PSendStatus

Enum PSendStatus 

pub enum PSendStatus {
    Ok,
    SocketNotAvailable,
    NoRouteToReciever,
    SignalInteruption,
    BrokenBackend,
    BrokenSocket,
    CannotSerializeData,
}
Describe the result of the send

  • Ok : Everything is OK
  • SocketNotAvailable : The socket is not available
  • NoRouteToReciever : The reciever cannot be reached, maybe caused by network problem
  • SignalInteruption : The socket cought a signal
  • BrokenBackend : The backend is broken
  • BrokenSocket : The socket is broken and cannot longer be used
  • CannotSerializeData : The data cannot be serialized in the message. Could happened from the DataStream if some types do not implement well the DataStream trait.

Variants



Ok

Everything is OK



SocketNotAvailable

The socket is not available



NoRouteToReciever

The reciever cannot be reached, maybe caused by network problem



SignalInteruption

The socket cought a signal. This value exist because zeromq socket tends to take it very badly when it recieves a signal. Thus, this is quite anoying and we have to take that int account



BrokenBackend

The backend is broken



BrokenSocket

The socket is broken and cannot longer be used



CannotSerializeData

The data cannot be serialized in the message